#
# spec file for package vectorscan
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
%define sover 5
%define so_suffix -vectorscan

Name:           vectorscan
Version:        5.4.11
Release:        2.1
Summary:        Regular expression matching library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/VectorCamp/vectorscan
Source:         https://github.com/VectorCamp/vectorscan/archive/refs/tags/vectorscan/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  boost-devel >= 1.57
BuildRequires:  cmake
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++ >= 9
%else
# Leap 15.x still uses gcc7 by default
BuildRequires:  gcc9-c++
%endif
BuildRequires:  libpcap-devel
BuildRequires:  pkgconfig
BuildRequires:  ragel
BuildRequires:  pkgconfig(sqlite3)
Conflicts:      hyperscan
# Do not support 32-bit Arm - https://github.com/VectorCamp/vectorscan/issues/61
# Same for 32-bit x86 - https://github.com/VectorCamp/vectorscan/issues/130
ExcludeArch:    %{ix86} %{arm}

%description
A fork of Intel's Hyperscan, modified to run on more platforms.

Vectorscan will follow Intel's API and internal algorithms where possible,
but will not hesitate to make code changes where it is thought of giving
better performance or better portability. In addition, the code will be
gradually simplified and made more uniform and all architecture specific
-currently Intel- #ifdefs will be removed and abstracted away.

%package -n libhs%{sover}%{so_suffix}%{sover}
Summary:        Regular expression matching library
Group:          System/Libraries
# Conflicts with libhs from Hyperscan
Conflicts:      libhs%{sover}

%description -n libhs%{sover}%{so_suffix}%{sover}
A fork of Intel's Hyperscan, modified to run on more platforms.

Vectorscan will follow Intel's API and internal algorithms where possible,
but will not hesitate to make code changes where it is thought of giving
better performance or better portability. In addition, the code will be
gradually simplified and made more uniform and all architecture specific
-currently Intel- #ifdefs will be removed and abstracted away.

%package examples
Summary:        Example binaries for the vectorscan library
Group:          Development/Libraries/C and C++

%description examples
Example binaries for the vectorscan library:
  hsbench, hscheck, patbench, pcapscan, simplegrep, unit-hyperscan

%package devel
Summary:        Libraries and header files for the vectorscan library
Group:          Development/Libraries/C and C++
Conflicts:      hyperscan-devel
Requires:       libhs%{sover}%{so_suffix}%{sover} = %version

%description devel
A fork of Intel's Hyperscan, modified to run on more platforms.

This package provides the libraries, include files and other resources
needed for developing Hyperscan applications.

%prep
%setup -q -n %{name}-%{name}-%{version}

%build
%if 0%{?suse_version} <= 1500
export CC=gcc-9
export CXX=g++-9
%endif
%cmake \
%ifarch aarch64 x86_64
  -DFAT_RUNTIME=ON \
%endif
  -DCMAKE_INSTALL_DOCDIR=%{_defaultdocdir}/%{name} \
%ifarch %{ix86} x86_64
  -DBUILD_AVX2=ON \
  -DBUILD_AVX512=ON \
%endif
  -DCMAKE_SKIP_RPATH=ON

%cmake_build

%install
%cmake_install
# Install examples
pushd build/
mkdir -p  %{buildroot}%{_bindir}
install bin/* %{buildroot}%{_bindir}
popd

%check
pushd build/
LD_LIBRARY_PATH=%{buildroot}%{_libdir} bin/unit-hyperscan
popd

%post -n libhs%{sover}%{so_suffix}%{sover} -p /sbin/ldconfig
%postun -n libhs%{sover}%{so_suffix}%{sover} -p /sbin/ldconfig

%files -n libhs%{sover}%{so_suffix}%{sover}
%license COPYING LICENSE
%{_libdir}/libhs.so.%{sover}*
%{_libdir}/libhs_runtime.so.%{sover}*

%files examples
%{_bindir}/*

%files devel
%{_libdir}/libhs.so
%{_libdir}/libhs_runtime.so
%{_libdir}/pkgconfig/libhs.pc
%{_includedir}/hs/
%dir %{_defaultdocdir}/%{name}
%dir %{_defaultdocdir}/%{name}/examples
%doc %{_defaultdocdir}/%{name}/examples/README.md
%doc %{_defaultdocdir}/%{name}/examples/*.cc
%doc %{_defaultdocdir}/%{name}/examples/*.c

%changelog
* Wed Apr  2 2025 Andreas Stieger <andreas.stieger@gmx.de>
- drop pcre build dependency used for hscollider which the package
  does not ship
* Tue Sep  3 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 5.4.11:
  * Fix clang 15,16 compilation errors on all platforms, refactor
    CMake build system by @markos in #181
  * Fix version getting out of sync #175 by @markos in #185
  * Ubuntu 20.04 gcc does not define HWCAP2_SVE2 #180 by @markos in #186
  * make pkgconfig a requirement by @markos in #188
  * Correct set_source_files_properties usage by @mlmitch in #189
  * Move VERM16 enums to the end of the list by @markos in #191
  * Merge with master by @markos in #192
  * prepare for 5.4.11 release by @markos in #196
  * release 5.4.11 by @markos in #197
  * Fix missing hs_version.h header (closes #198) by @gliwka in #199
  * fix missing installation of static libs by @markos in #200
  * Fix installation problems by @markos in #201
* Tue Sep 12 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 5.4.10.1:
  * Bugfix/disable fat macos arm
  * Fix compilation with libcxx 16
  * Fix use-of-uninitialized-value due to getData128()
  * Use std::vector instead of boost::container::small_vector under MSan
  * Feature/enable fat runtime arm
  * adding ifndef around HS_PUBLIC_API definition so that
    vectorscan can be statically linked into another shared
    library without exporting symbols
  * Feature/backport hyperscan 2023 q3
- Run unit-hyperscan in %%check
* Wed May  3 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- devel package must require libhs%%{sover}%%{so_suffix}%%{sover}
* Thu Apr  6 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 5.4.9:
  * Major change: Enable SVE & SVE2 builds and make it a
    supported architecture! (thanks to @abondarev84)
  * Fix various clang-related bugs
  * Fix Aarch64 bug in Parser.rl because of char signedness.
    Make unsigned char the default in the Parser for all architectures.
  * Fix Power bug, multiple tests were failing.
  * C++20 related change, use prefixed assume_aligned to avoid
    conflict with C++20 std::assume_aligned.
* Mon Oct 31 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Stop building machine-dependent binaries (boo#1100677)
* Fri Oct  7 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python
* Thu Sep 29 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use GCC9 for Leap/SLE 15.x to fix build
* Fri Sep 16 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 5.4.8:
  * New Vectorscan release, 5-10%% faster than 5.4.7 on Arm,
    10-20%% faster on Power.
  * CMake: Use non-deprecated method for finding python by @jth
    in #108
  * Optimize vectorscan for aarch64 by using shrn instruction by
    @danlark1 in #113
  * Fixed the PCRE download location by @pareenaverma in #116
  * Bugfix/hyperscan backport 202208 by @markos in #118
  * VSX optimizations by @markos in #119
  * when compiling with mingw64, use __mingw_aligned_malloc() and
    __mingw_aligned_free() by @liquidaty in #121
  * [NEON] simplify/optimize shift/align primitives by @markos
    in #123
  * Merge develop to master by @markos in #124
- Drop upstream patch:
  * vectorscan-add-missing-header.patch
* Tue Jul  5 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to add missing header:
  * vectorscan-add-missing-header.patch
* Tue May 31 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 5.4.7:
  * Fix word boundary assertions under C++20 by @BigRedEye in #90
  * Fix all ASAN issues in vectorscan by @danlark1 in #93
  * change FAT_RUNTIME to a normal option so it can be set to off by @a16bitsysop in #94
  * Optimized and correct version of movemask128 for ARM by @danlark1 in #102
* Tue Mar 15 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Version 5.4.6
